@@ -2,7 +2,7 @@
 
 from __future__ import absolute_import
 from CloudflareAPI.cloudflare import Cloudflare
-from CloudflareAPI.utils import jsonPrint, Fetch
+from CloudflareAPI.utils import Fetch, wait_result
 
 
-__ALL__ = ["Cloudflare", "jsonPrint", "Fetch"]
+__ALL__ = ["Cloudflare", "Fetch", "wait_result"]
