@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
 from typing import Optional
-from CloudflareAPI.core import CFBase, Request
+from CloudflareAPI.core import CFBase
 from CloudflareAPI.api import Account, Worker, Storage, User
 
 
@@ -13,8 +13,8 @@ class Cloudflare(CFBase):
             self.worker = self.get_worker()
             self.store = self.get_store()
 
-    def get_worker(self):
+    def get_worker(self) -> Worker:
         return Worker(account_id=self.account.id)
 
-    def get_store(self):
+    def get_store(self) -> Storage:
         return Storage(account_id=self.account.id)
